/*
 * Please do not edit this file.
 * It was generated using rpcgen.
 */

#ifndef _DRAC_H_RPCGEN
#define _DRAC_H_RPCGEN

#define RPCGEN_VERSION	199506

#include <rpc/rpc.h>

#ifndef CLIENT
#include <rpc/rpc.h>
#endif

struct drac_add_parm {
	u_long ip_addr;
};
typedef struct drac_add_parm drac_add_parm;
#ifdef __cplusplus
extern "C" bool_t xdr_drac_add_parm(XDR *, drac_add_parm*);
#elif __STDC__
extern  bool_t xdr_drac_add_parm(XDR *, drac_add_parm*);
#else /* Old Style C */
bool_t xdr_drac_add_parm();
#endif /* Old Style C */


enum addstat {
	ADD_SUCCESS = 0,
	ADD_PERM = 1,
	ADD_SYSERR = 2,
	ADD_UNKOWN = 3,
};
typedef enum addstat addstat;
#ifdef __cplusplus
extern "C" bool_t xdr_addstat(XDR *, addstat*);
#elif __STDC__
extern  bool_t xdr_addstat(XDR *, addstat*);
#else /* Old Style C */
bool_t xdr_addstat();
#endif /* Old Style C */


#define DRACPROG ((u_long)900101)
#define DRACVERS ((u_long)1)

#ifdef __cplusplus
#define DRACPROC_ADD ((u_long)1)
extern "C" addstat * dracproc_add_1(drac_add_parm *, CLIENT *);
extern "C" addstat * dracproc_add_1_svc(drac_add_parm *, struct svc_req *);

#elif __STDC__
#define DRACPROC_ADD ((u_long)1)
extern  addstat * dracproc_add_1(drac_add_parm *, CLIENT *);
extern  addstat * dracproc_add_1_svc(drac_add_parm *, struct svc_req *);

#else /* Old Style C */
#define DRACPROC_ADD ((u_long)1)
extern  addstat * dracproc_add_1();
extern  addstat * dracproc_add_1_svc();
#endif /* Old Style C */

#endif /* !_DRAC_H_RPCGEN */
